Changelog
=========

1.2.1 (2019-05-15)
------------------

- Remove 'products' directory registration for buildout recipe
  [erral]

- update varnish control script in supervisor.
  [erral]


1.2 (2019-04-04)
----------------

- Always cache Diazo rules in development
  [erral]

- Enable WSGI
  [erral]

- Update pinnings
  [erral]

- Remove checkinterval calculation.
- Python3 compatibility fixes
  [erral]


1.1.4 (2019-01-24)
------------------

- Fix template registration
  [erral]


1.1.3 (2019-01-24)
------------------

- Minor fixes in template registration.
  [erral]


1.1.2 (2019-01-16)
------------------

- Bugfixes in migration subtemplate.
  [erral]


1.1.1 (2018-11-26)
------------------

- Minor fix.
  [erral]

1.1 (2018-11-26)
----------------

- Add a subtemplate with migration utils.
  [erral]


1.0.0 (2018-10-19)
------------------

- Link to starzel buildout for hotfix installation
  [erral]

- Improve docs
  [erral]

- More tests
  [erral]

1.0b1 (2018-10-18)
------------------

- No changes yet.
